/***************************************************************************
 *                                                                         *
 *  Filename : Dimension.c                                                 *
 *                                                                         *
 *  Description : Routines for computing dimensions of Lie groups and      *
 *                representations of Lie groups.                           *
 *                                                                         *
 ***************************************************************************
 *                                                                         *
 *                         Modification History                            *
 *                                                                         *
 *  Date      Author       Comments                                        *
 * ----------------------------------------------------------------------  *
 *  9.8.93    R.Bdi       Created.                                        *
 *                                                                         *
 ***************************************************************************
 *                                                                         *
 * Copyright ) 1993 Michael Joswig, Richard Bdi.  All rights reserved.    *
 *                                                                         *
 ***************************************************************************/

/*----------------------------- INCLUDES ----------------------------------*/

#include "IrrReps.h"
#include "Protos.h"

/*------------------------------- CODE ------------------------------------*/


/***************************************************************************
 *                                                                         *
 *  Function name : GroupDimension ()                                      *
 *                                                                         *
 *  Description : Computes the (real) dimension of a Liegroup.             *
 *                                                                         *
 ***************************************************************************
 *                                                                         *
 *  Synopsis : GroupDimension (*Group)                                     *
 *                                                                         *
 *  Parameters :                                                           *
 *    (struct LiegroupClass) *Group:                                       *
 *       Pointer to a LiegroupClass structure which contains the data of   *
 *       the group.                                                        *
 *                                                                         *
 *  Return value :                                                         *
 *    (double)                                                             *
 *       Returns the (real) dimension of a Liegroup.                       *
 *       Returns 0, if the spacified Liegroup does not exist.              *
 *       Note that we use a double instead of an unsigned long since       *
 *       the rank of the Liegroup is an unsigned long und hence the        *
 *       dimension can exceed MAX_ULONG.                                   *
 *                                                                         *
 ***************************************************************************/

double   GroupDimension (struct LiegroupClass *Group)

{
double         GDim = 0;
unsigned long  E[3] = {78, 133, 248};

switch (Group->type)
   {
   case 'A':
      GDim = (double)(Group->rank * Group->rank + 2 * Group->rank);
      break;
   case 'B':
   case 'C':
      GDim = (double)(2 * Group->rank * Group->rank + Group->rank);
      break;
   case 'D':
      GDim = (double)(2 * Group->rank * Group->rank - Group->rank);
      break;
   case 'E':
      if ((Group->rank >= 6) || (Group->rank <= 8)) GDim = (double)(E[Group->rank - 6]);
      break;
   case 'F':
      if (Group->rank == 4) GDim = (double)52;
      break;
   case 'G':
      if (Group->rank == 2) GDim = (double)14;
      break;
   }

return (GDim);
}


/*--------------------------- END OF FILE ---------------------------------*/
