/***************************************************************************
 *                                                                         *
 *  Filename : IrrReps.h                                                   *
 *                                                                         *
 *  Description : Header file for reopresentation package.                 *
 *                                                                         *
 ***************************************************************************
 *                                                                         *
 *                         Modification History                            *
 *                                                                         *
 *  Date      Author       Comments                                        *
 * ----------------------------------------------------------------------  *
 *  9.4.93    R.Boedi      Created.                                        *
 * 22.5.93    R.Boedi      Changed struct Matrix to fit better for OOP.    *
 *  7.8.93    M.Joswig     Introduced additional ErrorType RANGE_ERROR.    *
 *  8.8.93    M.Joswig     Introduced additional ErrorType MEM_ERROR.      *
 *  9.8.93    R.Boedi      Added new structures LGNode and RepNode.        *
 * 10.8.93    R.Boedi      Added new enum type ElementeType.               *
 * 20.8.93    M.Joswig     Introduced additional ErrorType TYPE_ERROR.     *
 *                         Introduced additional AlgebraType SET_OF_TYPES. *
 * 25.8.93    M.Joswig     Introduced additional Type RepList.             *
 * 30.3.94    MJ/RB        Changed enum type InputType to ErrorType and    *
 *                         added OVERFLOW_ERROR.                           *
 *                                                                         *
 ***************************************************************************
 *                                                                         *
 * Copyright (C) 1993 Richard Boedi, Michael Joswig.  All rights reserved. *
 *                                                                         *
 ***************************************************************************/

/*----------------------------- INCLUDES ----------------------------------*/

#define _STRICT_ANSI          /* Only for the AMIGA version to insure full ANSI
                                 compatibility */

#include "string.h"
#include "stdio.h"
#include "stdlib.h"
#include "math.h"
#include "limits.h"
#include "ctype.h"

/*---------------------------- DEFINES -----------------------------------*/

#define  VERSION        " 1.01 (27-Jan-95) "

#define  TRUE           1
#define  FALSE          0

#define  NO_INDEX      -9999

#define  InnerLeft      '('
#define  InnerRight     ')'
#define  OuterLeft      '['
#define  OuterRight     ']'
#define  Delim          ','
#define  WildCard       '*'

#define  COMPSIZE      16    /* size in bytes for a long integer, seen as a string. */

/*---------------------- STRUCTURE DEFINITIONS ---------------------------*/

typedef  unsigned char   BOOL;
typedef  struct LGNode  *LGList;
typedef  struct RepNode *RepList;

enum FieldType    { COMPLEX, R, C, H = 4, UNSPECIFIED = 99 };
enum AlgebraType  { DONT_EXIST, REAL_ALG, COMPLEX_ALG, SET_OF_TYPES };
enum ErrorType    { NO_ERROR, SYNTAX_ERROR, WRONG_LENGTH, RANGE_ERROR, OVERFLOW_ERROR, MEM_ERROR, TYPE_ERROR };
enum ElementType  { SIGNED, UNSIGNED };

struct LiegroupClass
   {
   char              type;              /* WildCard is '*' */
   unsigned long     rank;              /* WildCard is 0 */
   enum FieldType    field;             /* WildCard is UNSPECIFIED */
   long              index;             /* WildCard is NO_INDEX */
   };

struct Vector
   {
   unsigned long     length;
   long             *elements;
   };

struct Matrix                            /* With this definition a matrix */
   {                                     /* can easily be regarded as a vector. */
   unsigned long     length;             /* usually set to rows * columns */
   long             *elements;
   unsigned long     rows, columns;
   long            **prow;               /* pointer array to the rows */
   };

struct LGNode
   {
   struct LGNode          *NextNode;
   struct LiegroupClass    LGC;
   };

struct RepNode
   {
   struct RepNode   *NextNode;
   unsigned long     dimension;
   enum FieldType    centralizer;
   struct Vector     weight;
   };


/*------------------------ END OF HEADER FILE ----------------------------*/

