/***************************************************************************
 *                                                                         *
 *  Filename : Protos.h                                                    *
 *                                                                         *
 *  Description : Contains all function prototypes for IrrReps             *
 *                                                                         *
 ***************************************************************************
 *                                                                         *
 *                         Modification History                            *
 *                                                                         *
 *  Date      Author       Comments                                        *
 * ----------------------------------------------------------------------  *
 *  9.4.93    R.Boedi      Created.                                        *
 *  5.8.93    R.Boedi      Changed memory allocation for vectors and       *
 *                         matrices, see file Memory.c                     *
 *  9.8.93    M.Joswig	   Added prototypes for file LGList.               *
 * 10.8.93    R.Boedi      Added Type parameter in PrintVector(),          *
 *                         PrintMatrix(), and VectorToString().            *
 * 11.8.93    R.Boedi      Changed return value of function CreateRepTable.*
 * 24.8.93    RB/MJ        Added gcd prototype.                            *
 * 25.8.93    M.Joswig     Added "Reverse" prototype.                      *
 * 22.9.93    R.Boedi      Changed parameters of functions PrintMatrix()   *
 *                         and CreateRepTable().                           *
 * 30.3.94    MJ/RB        Changed return value of DimIrrRep() to enum     *
 *                         ErrorType. Added functions VMult() and          *
 *                         SetLimits().                                    *
 * 31.3.94    MJ/RB        Added function PrintLGClass().                  *
 *                                                                         *
 ***************************************************************************
 *                                                                         *
 * Copyright (C) 1993 Richard Boedi, Michael Joswig.  All rights reserved. *
 *                                                                         *
 ***************************************************************************/

/*--------------------- FUNCTION PROTOTYPES -------------------------------*/

/* File Memory.c */
struct Vector    *CreateVector (unsigned long);
struct Matrix    *CreateMatrix (unsigned long, unsigned long);
LGList            LGConstruct (char, unsigned long, enum FieldType, long, LGList);
RepList 				RepListConstruct (struct Vector *, unsigned long, unsigned int, struct RepNode *);
RepList    			Reverse (RepList);
void              FreeVector (struct Vector *);
void              FreeMatrix (struct Matrix *);
void              FreeLGList (LGList);
void              FreeRepList (RepList);

/* File LGList.c */
BOOL 					LGinList (struct LiegroupClass *, LGList);
BOOL 					LGinListNoCheck (struct LiegroupClass *, LGList);

/* File gcd.c */
unsigned long     gcd_cf (unsigned long, unsigned long, long *, long *);
unsigned long     gcd (unsigned long, unsigned long);

/* File Convert.c */
enum ErrorType    StringToVector (char *, struct Vector *);
char             *VectorToString (struct Vector *, char *, unsigned short *, enum ElementType);
enum ErrorType    StringToLGClass (struct LiegroupClass *, char *);

/* File Arith.c */
BOOL              VectorNull (struct Vector *);
BOOL              VectorCmp (struct Vector *, struct Vector *);
struct Vector    *VectorAdd (struct Vector *, struct Vector *);
struct Vector    *VectorMult (long, struct Vector *);
struct Vector    *VectorRemainder (struct Vector *, unsigned long);
enum ErrorType    VMult (unsigned long, unsigned long, unsigned long *);

/* File Dim.c */
double            GroupDimension (struct LiegroupClass *);

/* File ChckType.c */
enum AlgebraType  CheckType (struct LiegroupClass *);
BOOL              LGinList (struct LiegroupClass *, LGList);

/* File PosRoots.c */
unsigned long     NoOfPositiveRoots (struct LiegroupClass *);
struct Vector    *PositiveRootNorms (struct LiegroupClass *);
struct Matrix    *PositiveRoots (struct LiegroupClass *);
struct Matrix    *CartanMatrix (struct LiegroupClass *);
struct Vector    *Exponents (struct LiegroupClass *);
void              SetLimits (void);

/* File Weyl.c */
enum ErrorType    DimIrrRep (struct LiegroupClass *, struct Vector *, unsigned long *);
unsigned long     DivideInteger (struct Vector *, struct Vector *);

/* File WeightC.c */
struct Vector    *WeightConj (struct LiegroupClass *, struct Vector *);
struct Vector    *ContraGradient (struct LiegroupClass *, struct Vector *);
struct Vector    *PermuteVector (struct Vector *, struct Vector *, struct Vector *);

/* File Index.c */
unsigned int      IndexFundRep (struct LiegroupClass *, unsigned long);
unsigned int      IndexRep (struct LiegroupClass *, struct Vector *);
enum FieldType    Centralizer (struct LiegroupClass *, struct Vector *);

/* File Center.c */
struct Vector   *CenterUC (struct LiegroupClass *);

/* File Image.c */
struct Vector    *ImageFundRep (struct LiegroupClass *, unsigned long);
struct Vector    *ImageRep (struct LiegroupClass *, struct Vector *);

/* File Kernel.c */
struct Matrix    *Kernel (struct LiegroupClass *, struct Vector *);
struct Matrix    *KernelReal (struct LiegroupClass *, struct Vector *);
struct Matrix    *KernelComplex (struct LiegroupClass *, struct Vector *);

/* File Output.c */
BOOL              PrintVector (struct Vector *, unsigned short *, enum ElementType);
BOOL              PrintMatrix (struct Matrix *, enum ElementType, BOOL);
void              PrintLGClass (struct LiegroupClass *);
/* File Table.c */
long              CreateRepTable (struct LiegroupClass *, unsigned long, unsigned long, BOOL);
int               qsortCompare (const void *, const void *);

/*------------------ END OF FUNCTION PROTOTYPES ---------------------------*/
